@@ -38,7 +38,7 @@ def hash_bytes(buf):
     Hash bytes using the same method the registry uses (currently SHA-256).
 
     :param buf: Bytes to hash
-    :type buf: str
+    :type buf: binary str
 
     :rtype: str
     :returns: Hex-encoded hash of file's content
@@ -107,6 +107,22 @@ class _ReportingChunks(object):
                 self._cb(self._dgst, chunk)
             yield chunk
 
+class PaginatingResponse(object):
+    # pylint: disable=too-few-public-methods
+    def __init__(self, dxf_obj, req_meth, path, header, **kwargs):
+        self._meth = getattr(dxf_obj, req_meth)
+        self._path = path
+        self._header = header
+        self._kwargs = kwargs
+    def __iter__(self):
+        while self._path:
+            response = self._meth('get', self._path, **self._kwargs)
+            self._kwargs = {}
+            for v in response.json()[self._header]:
+                yield v
+            nxt = response.links.get('next')
+            self._path = nxt['url'] if nxt else None
+
 class DXFBase(object):
     # pylint: disable=too-many-instance-attributes
     """
@@ -123,7 +139,8 @@ class DXFBase(object):
     returned by :meth:`DXF.pull_blob` then the underlying connection won't be
     closed until Python garbage collects the iterator.
     """
-    def __init__(self, host, auth=None, insecure=False, auth_host=None):
+    def __init__(self, host, auth=None, insecure=False, auth_host=None, tlsverify=True):
+        # pylint: disable=too-many-arguments
         """
         :param host: Host name of registry. Can contain port numbers. e.g. ``registry-1.docker.io``, ``localhost:5000``.
         :type host: str
@@ -136,6 +153,9 @@ class DXFBase(object):
 
         :param auth_host: Host to use for token authentication. If set, overrides host returned by then registry.
         :type auth_host: str
+
+        :param tlsverify: When set to False, do not verify TLS certificate.
+        :type tlsverify: bool
         """
         self._base_url = ('http' if insecure else 'https') + '://' + host + '/v2/'
         self._auth = auth
@@ -145,6 +165,14 @@ class DXFBase(object):
         self._headers = {}
         self._repo = None
         self._sessions = [requests]
+        self._tlsverify = tlsverify
+        if not tlsverify:
+            try:
+                from requests.packages import urllib3
+            except ImportError:
+                import urllib3
+            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+
 
     @property
     def token(self):
@@ -164,7 +192,7 @@ class DXFBase(object):
 
     def _base_request(self, method, path, **kwargs):
         def make_kwargs():
-            r = {'allow_redirects': True}
+            r = {'allow_redirects': True, 'verify': self._tlsverify}
             r.update(kwargs)
             if 'headers' not in r:
                 r['headers'] = {}
@@ -211,7 +239,7 @@ class DXFBase(object):
         if self._insecure:
             raise exceptions.DXFAuthInsecureError()
         if response is None:
-            response = self._sessions[0].get(self._base_url)
+            response = self._sessions[0].get(self._base_url, verify=self._tlsverify)
         # pylint: disable=no-member
         if response.status_code != requests.codes.unauthorized:
             raise exceptions.DXFUnexpectedStatusCodeError(response.status_code,
@@ -244,21 +272,30 @@ class DXFBase(object):
             if self._auth_host:
                 url_parts[1] = self._auth_host
             auth_url = urlparse.urlunparse(url_parts)
-            r = self._sessions[0].get(auth_url, headers=headers)
+            r = self._sessions[0].get(auth_url, headers=headers, verify=self._tlsverify)
             _raise_for_status(r)
             self.token = r.json()['token']
             return self._token
         else:
             self._headers = headers
 
-    def list_repos(self):
+    def list_repos(self, batch_size=None, iterate=False):
         """
         List all repositories in the registry.
 
-        :rtype: list
-        :returns: List of repository names.
+        :param batch_size: Number of repository names to ask the server for at a time.
+        :type batch_size: int
+
+        :param iterate: Whether to return iterator over the names or a list of all the names.
+        :type iterate: bool
+
+        :rtype: list or iterator of strings
+        :returns: Repository names.
         """
-        return self._base_request('get', '_catalog').json()['repositories']
+        it = PaginatingResponse(self, '_base_request',
+                                '_catalog', 'repositories',
+                                params={'n': batch_size})
+        return it if iterate else list(it)
 
     def __enter__(self):
         assert self._sessions
@@ -276,8 +313,8 @@ class DXF(DXFBase):
     """
     Class for operating on a Docker v2 repositories.
     """
-    # pylint: disable=too-many-arguments
-    def __init__(self, host, repo, auth=None, insecure=False, auth_host=None):
+    def __init__(self, host, repo, auth=None, insecure=False, auth_host=None, tlsverify=True):
+        # pylint: disable=too-many-arguments
         """
         :param host: Host name of registry. Can contain port numbers. e.g. ``registry-1.docker.io``, ``localhost:5000``.
         :type host: str
@@ -293,8 +330,11 @@ class DXF(DXFBase):
 
         :param auth_host: Host to use for token authentication. If set, overrides host returned by then registry.
         :type auth_host: str
+
+        :param tlsverify: When set to False do not verify TLS certificate
+        :type tlsverify: bool
         """
-        super(DXF, self).__init__(host, auth, insecure, auth_host)
+        super(DXF, self).__init__(host, auth, insecure, auth_host, tlsverify)
         self._repo = repo
 
     def _request(self, method, path, **kwargs):
@@ -305,6 +345,7 @@ class DXF(DXFBase):
                   progress=None,
                   data=None, digest=None,
                   check_exists=True):
+        # pylint: disable=too-many-arguments
         """
         Upload a file to the registry and return its (SHA-256) hash.
 
@@ -457,8 +498,8 @@ class DXF(DXFBase):
         :param alias: Alias name
         :type alias: str
 
-        :param digests: List of blob hashes (strings).
-        :type digests: list
+        :param digests: List of blob hashes.
+        :type digests: list of strings
 
         :rtype: str
         :returns: The registry manifest used to define the alias. You almost definitely won't need this.
@@ -585,14 +626,23 @@ class DXF(DXFBase):
         self._request('delete', 'manifests/{}'.format(dcd))
         return dgsts
 
-    def list_aliases(self):
+    def list_aliases(self, batch_size=None, iterate=False):
         """
         List all aliases defined in the repository.
 
-        :rtype: list
-        :returns: List of alias names (strings).
+        :param batch_size: Number of alias names to ask the server for at a time.
+        :type batch_size: int
+
+        :param iterate: Whether to return iterator over the names or a list of all the names.
+        :type iterate: bool
+
+        :rtype: list or iterator of strings
+        :returns: Alias names.
         """
-        return self._request('get', 'tags/list').json()['tags']
+        it = PaginatingResponse(self, '_request',
+                                'tags/list', 'tags',
+                                params={'n': batch_size})
+        return it if iterate else list(it)
 
 # v1 schema support functions below
 
@@ -628,11 +678,15 @@ def _sign_manifest(manifest_json):
     format_tail = manifest_json[format_length:]
     key = jwk.JWK.generate(kty='EC', crv='P-256')
     jwstoken = jws.JWS(manifest_json.encode('utf-8'))
+    jkey = json.loads(key.export_public())
+    # Docker expects 32 bytes for x and y
+    jkey['x'] = _urlsafe_b64encode(_urlsafe_b64decode(jkey['x']).rjust(32, b'\0'))
+    jkey['y'] = _urlsafe_b64encode(_urlsafe_b64decode(jkey['y']).rjust(32, b'\0'))
     jwstoken.add_signature(key, None, {
         'formatLength': format_length,
         'formatTail': _urlsafe_b64encode(format_tail)
     }, {
-        'jwk': json.loads(key.export_public()),
+        'jwk': jkey,
         'alg': 'ES256'
     })
     return manifest_json[:format_length] + \
